import React, { useEffect, useState } from "react";
import {
  GridComponent,
  ColumnDirective,
  ColumnsDirective,
  Page,
  Inject,
  Filter,
  Group,
  Edit,
  EditSettingsModel,
  Toolbar,
  ToolbarItems,
} from "@syncfusion/ej2-react-grids";
import { Ajax } from "@syncfusion/ej2-base";
import { DataManager, UrlAdaptor } from "@syncfusion/ej2-data";
import { ICourseModel } from "./courseModel";
import { DialogFormTemplate } from "./DialogFormTemplate";
import {
  getCourse,
  addCourse,
  updateCourse,
  deleteCourse,
} from "./courseService";
import "./App.css";

function App() {
  const [data, setData] = useState([]);
  const editOptions: EditSettingsModel = {
    allowEditing: true,
    allowAdding: true,
    allowDeleting: true,
    newRowPosition: "Top",
    /*mode: "Dialog",
    template: dialogTemplate,*/
  };
  const toolbarOptions: ToolbarItems[] = [
    "Add",
    "Edit",
    "Delete",
    "Update",
    "Cancel",
  ];
  const baseURL: string = "http://localhost:8081";
  /*const data: DataManager = new DataManager({
    adaptor: new UrlAdaptor(),
    insertUrl: baseURL + "/insert-course",
    removeUrl: baseURL + "/delete-course",
    updateUrl: baseURL + "/update-course",
    url: baseURL + "/fetch-course",
  });*/
  useEffect(() => {
    /* const ajax = new Ajax("fetch-course", "GET");
    ajax.send();
    ajax.onSuccess = (data: any) => {
      setData(JSON.parse(data));
    };*/
    getCourse().then((data) => {
      setData(data);
    });
  }, []);
  function dialogTemplate(props: ICourseModel): any {
    return <DialogFormTemplate {...props} />;
  }
  function dataSourceChanged(state: any) {
    console.log("here");
    if (state.action == "add") {
      addCourse(state.data);
    } else if (state.action == "edit") {
    } else if (state.requestType == "delete") {
    }
  }
  return (
    <div style={{ margin: "10%", marginTop: "5%" }}>
      <GridComponent
        dataSource={data}
        allowPaging={true}
        pageSettings={{ pageSize: 6 }}
        allowFiltering={true}
        allowGrouping={true}
        editSettings={editOptions}
        toolbar={toolbarOptions}
        dataSourceChanged={dataSourceChanged}
      >
        <ColumnsDirective>
          <ColumnDirective
            field="id"
            headerText="Course ID"
            textAlign="Right"
            width="100"
            isPrimaryKey={true}
          />
          <ColumnDirective field="name" headerText="Course Name" width="150" />
          <ColumnDirective field="domain" headerText="Domain" />
          <ColumnDirective field="description" headerText="Description" />
        </ColumnsDirective>
        <Inject services={[Page, Filter, Group, Edit, Toolbar]} />
      </GridComponent>
    </div>
  );
}

export default App;
